@@ -125,10 +125,9 @@ cuesheet_widget_renderer_state_changed_cb (MafwRenderer *renderer,
 
 		case Stopped:
 			/* Remove the timout handler: */
-			if (priv->timer) {
+			if (priv->timer)
 				g_source_remove (priv->timer);
-				priv->timer = 0;
-			}
+			priv->timer = 0;
 
 			gtk_label_set_text (GTK_LABEL (priv->performer), _("(no track informations)"));
 			gtk_widget_hide (priv->title);
@@ -137,10 +136,9 @@ cuesheet_widget_renderer_state_changed_cb (MafwRenderer *renderer,
 		case Paused:
 		case Transitioning:
 			/* Remove the timout handler: */
-			if (priv->timer) {
+			if (priv->timer)
 				g_source_remove (priv->timer);
-				priv->timer = 0;
-			}
+			priv->timer = 0;
 			break;
 		default:
 			break;
@@ -317,6 +315,25 @@ cuesheet_widget_renderer_media_changed_cb (MafwRenderer *renderer,
 	}
 }
 
+static void
+cuesheet_widget_renderer_current_metadata (MafwRenderer *self,
+					   const gchar *object_id,
+					   GHashTable *metadata,
+					   gpointer user_data,
+					   const GError *error)
+{
+	CueSheetWidget *priv = CUESHEET_WIDGET (user_data);
+
+	g_return_if_fail (priv);
+
+	if (error != NULL) {
+		g_warning ("cuesheet_widget_renderer_current_metadata_cb: %s", error->message);
+		return;
+	}
+
+	cuesheet_widget_renderer_media_changed_cb (self, 0, object_id, priv);
+}
+
 static void
 cuesheet_widget_renderer_status_cb (MafwRenderer *self,
 				    MafwPlaylist *playlist,
@@ -335,12 +352,7 @@ cuesheet_widget_renderer_status_cb (MafwRenderer *self,
 		return;
 	}
 
-	cuesheet_widget_renderer_media_changed_cb (self, index, object_id, priv);
-
-	if (state == Playing) {
-		priv->timer = g_timeout_add (2000, cuesheet_widget_renderer_on_timeout,
-					     priv);
-	}
+	cuesheet_widget_renderer_state_changed_cb (self, state, priv);
 }
 
 static void
@@ -406,6 +418,10 @@ cuesheet_widget_renderer_added_cb (MafwRegistry *registry,
 					  G_CALLBACK (cuesheet_widget_renderer_state_changed_cb),
 					  priv);
 
+			/* force update of metadata */
+			mafw_renderer_get_current_metadata (MAFW_RENDERER (renderer),
+							    cuesheet_widget_renderer_current_metadata, priv);
+
 			/* force update of status */
 			mafw_renderer_get_status (MAFW_RENDERER (renderer),
 						  cuesheet_widget_renderer_status_cb, priv);
@@ -502,14 +518,14 @@ cuesheet_widget_on_current_desktop (GtkWidget *widget,
 	g_object_get (widget, "is-on-current-desktop", &on, NULL);
 	if (!on) {
 		/* Remove the timout handler: */
-		if (priv->timer) {
+		if (priv->timer)
 			g_source_remove (priv->timer);
-			priv->timer = 0;
-		}
+		priv->timer = 0;
 	} else {
-		if (priv->cuesheet_available) {
-			priv->timer = g_timeout_add (2000, cuesheet_widget_renderer_on_timeout,
-						     priv);
+		/* force update of status */
+		if (priv->renderer) {
+			mafw_renderer_get_status (MAFW_RENDERER (priv->renderer),
+						  cuesheet_widget_renderer_status_cb, priv);
 		}
 	}
 }
